## 目录结构说明
.
├── assert_demo.py
├── demo1.py
├── readme.md
├── 测试物料             
│   ├── readme.md
│   └── login.py
├── 测试场景             #所有的测试场景都应该放到这个目录，不建议删除此目录
│   ├── readme.md
│   └──demo1.py
└── run_test_suite.py   #所有的TestSuite 都应该放到这里，不建议删除此目录


